const fs = require('fs')
const { parse } = require('csv-parse')

export async function readAndGroupCSV(csvPath) {
    // 定义一个根据 type 判断长度的简单示例
    const typeLengthMap = {
        int: 1,
        word: 1, // 仅示例，如需更多类型可自行扩充
        bool: 1
    }

    // 存放最终按 pageName 分组的结果
    // 结构示例: { index: [{ name, address, length }, ...], login: [...], ... }
    const groupedData = {}

    return new Promise((resolve, reject) => {
        fs.createReadStream(csvPath)
            .pipe(parse({ delimiter: ',', from_line: 2 })) // 跳过表头
            .on('data', (row) => {
                console.log('row', row)
                // 假设 CSV 列顺序为: pageName, varName, addr, bit, type
                const [pageName, varName, addr, bit, type] = row

                const length = typeLengthMap[type] || 1  // 如果未匹配到, 默认 1

                // 初始化分组数组
                if (!groupedData[pageName]) {
                    groupedData[pageName] = []
                }

                groupedData[pageName].push({
                    name: varName,
                    address: parseInt(addr, 10),
                    length
                })
            })
            .on('error', (err) => {
                reject(err)
            })
            .on('end', () => {
                resolve(groupedData)
            })
    })
}

