import { readAndGroupCSV } from './init'
const ModbusRTU = require('modbus-serial')


let client
// 寄存器循环
let time = null
// 前端所需的数据的寄存器地址
let monitorPointList = []
// 传给前端的数据
let returnData = []
// 读取csv文件的结果
let csvResult = {}

// 示例调用
readAndGroupCSV('c:/document/code/electron/electron/electron/electron-app/resources/init.csv')
    .then((result) => {
        // console.log(JSON.stringify(result, null, 2))
        csvResult = result
        // 在此处可以将 result 提供给后续逻辑使用
    })
    .catch((err) => {
        console.error('read CSV err:', err)
    })


// 连接modbus
export function login(event, message) {
    // 创建modbus连接
    client = new ModbusRTU()
    client.setTimeout(2000);
    // console.log('client', message)
    // 根据IP连接modbus
    client.connectTCP(message.ip, { port: 502 }, function (err) {
        if (err) {
            console.log('login err', err)
            event.reply('loginReply', { code: 4, message: '连接失败', err })
            return
        }
        console.log('login success')
        event.reply('loginReply', { code: 200, message: '连接成功' })
    }
    )
}

// 包装回调为 Promise
function readRegisterAsync(address, quantity) {
    return new Promise((resolve, reject) => {
        console.log('address', address, 'quantity', quantity)
        client.readHoldingRegisters(address, quantity, (err, data) => {
            if (err) {
                return reject(err)
            }
            // 假设只提取 data[0]，可根据需求调整
            resolve(data.data[0])
        })
    })
}

// 根据页面需要的数据读取寄存器（定义一个读取寄存器并返回数据到渲染进程的方法）
async function readClient(event, message) {
    try {
        // 不重复清空 returnData 的话，会导致数据越堆越多，先清空
        returnData = []
        // 通过获取的页面所需的寄存器地址，循环读取寄存器（生成多个并发请求）
        const requests = monitorPointList.map(({ address, length }) =>
            readRegisterAsync(address, length)
        )

        // 并发读取所有寄存器
        const results = await Promise.all(requests)
        console.log('results', results)

        // 将结果存储到 returnData
        returnData.push(...results)

        // 将结果发送给前端
        sendData(event, returnData)
    } catch (error) {
        console.error('read err', error)
        event.reply('readReply', { code: 5, message: '读取失败', err })
    }

}

// 向前端发送数据。读取成功，拿到页面关键词，返回页面对应的数据
function sendData(event, data) {
    let result = monitorPointList.map((entry, i) => ({
        varName: entry.name,
        value: data[i], // 这里假设 data[i] 是对应的值
    }))
    console.log('result', result)
    event.reply('readReply', { code: 200, message: '读取成功', data: result })

}

// 获取页面关键词，判断页面
function getPageMonitorPointList(message) {
    // 根据页面关键词判断页面
    console.log('message', message)
    switch (message.pageName) {
        case 'index':
            console.log('index')
            // index 页面需要读取的数据的寄存器地址
            monitorPointList = csvResult['index']
            break
        case 'login':
            console.log('login')
            break
        default:
            break
    }
}

// 调用根据页面需要的数据读取寄存器的方法
export function read(event, message) {
    if (!(time == null)) {
        console.log('Reading data repeatedly', time)
        return
    }
    // 获取页面关键词，判断页面
    getPageMonitorPointList(message)
    // 循环读取寄存器
    time = setInterval(() => {
        readClient(event, message)
    }, 1000)
}

export function stopRead(event) {

    clearInterval(time)
    time = null
    console.log('stop')
    // 返回数据给渲染进程
    event.reply('readReply', [])
}

