import { shell, BrowserWindow } from 'electron'
import { join } from 'path'
import { is } from '@electron-toolkit/utils'
import icon from '../../resources/icon.png?asset'
// 主窗口
let mainWindow
// 登录窗口
let loginWindow


// 创建主窗口
export function createWindow() {
    // Create the browser window.
    mainWindow = new BrowserWindow({
        width: 900,
        height: 670,
        show: false,
        autoHideMenuBar: true,
        ...(process.platform === 'linux' ? { icon } : {}),
        webPreferences: {
            preload: join(__dirname, '../preload/index.js'),
            sandbox: false
        }
    })
    mainWindow.on('ready-to-show', () => {
        mainWindow.show()
    })

    mainWindow.webContents.setWindowOpenHandler((details) => {
        shell.openExternal(details.url)
        return { action: 'deny' }
    })

    // HMR for renderer base on electron-vite cli.
    // Load the remote URL for development or the local html file for production.
    if (is.dev && process.env['ELECTRON_RENDERER_URL']) {
        mainWindow.loadURL(process.env['ELECTRON_RENDERER_URL'] + '/#/login')
        // mainWindow.loadURL(process.env['ELECTRON_RENDERER_URL'] + '/#/main/index')
    } else {
        mainWindow.loadFile(join(__dirname, '../renderer/index.html'), { hash: 'login' })
        // mainWindow.loadFile(join(__dirname, '../renderer/index.html'), { hash: 'main/index' })
    }
}

// 创建子窗口
export function createChildWindow() {
    loginWindow = new BrowserWindow({
        parent: mainWindow,
        width: 500,
        height: 400,
        show: false,
        autoHideMenuBar: true,
        ...(process.platform === 'linux' ? { icon } : {}),
        webPreferences: {
            preload: join(__dirname, '../preload/index.js'),
            sandbox: false
        }
    })

    loginWindow.on('ready-to-show', () => {
        loginWindow.show()
    })

    loginWindow.webContents.setWindowOpenHandler((details) => {
        // console.log('details.url', details.url)
        shell.openExternal(details.url)
        return { action: 'deny' }
    })

    // HMR for renderer base on electron-vite cli.
    // Load the remote URL for development or the local html file for production.
    if (is.dev && process.env['ELECTRON_RENDERER_URL']) {
        // console.log(process.env['ELECTRON_RENDERER_URL'] + '/#/login')
        loginWindow.loadURL(process.env['ELECTRON_RENDERER_URL'] + '/#/login')
    } else {
        loginWindow.loadURL(join(__dirname, '../renderer/index.html'), { hash: 'login' })
    }
}

// export function login(event, message){
//     mainWindow.webContents.send('loginReply', message.ip)
//     loginWindow.close()
// }
export function login(event, message){
    mainWindow.webContents.send('loginReply', message.ip)
    loginWindow.close()
}

// 返回主窗口
export function getMainWindow() {
    return mainWindow
}
// 返回登录子窗口
export function getLoginWindow() {
    return loginWindow
}